@@ -491,6 +491,9 @@ test_that("Test call_path in a large number of variations", {
     )
   )
 
+  suppressWarnings({SDMTools_check <- requireNamespace('SDMTools', quietly = TRUE)})
+  if(!SDMTools_check) skip('Some tests require SDMTools - install it first')
+  
   CP_work4 <- workflow(
     occurrence = UKAnophelesPlumbeus,
     covariate = UKAir,
