@@ -17,24 +17,28 @@ test_that("repo modules pass", {
   expect_true(x <- zoon:::test_module(paste0(basepath,
                                              "Crossvalidate.R")))
 
-  # Model PA
-  expect_true(x <- zoon:::test_module(paste0(basepath,
-                                             "LogisticRegression.R")))
 
-  # Model PB
-  expect_true(x <- zoon:::test_module(paste0(basepath,
-                                             "MaxLike.R")))
+
+
 
   # Covariate
   expect_true(x <- zoon:::test_module(paste0(basepath,
                                              "UKAir.R")))
 
-  # Occurrence PO
-  expect_true(x <- zoon:::test_module(paste0(basepath,
-                                             "CarolinaWrenPO.R")))
+  suppressWarnings({SDMTools_check <- requireNamespace('SDMTools', quietly = TRUE)})
+  
+  if(!SDMTools_check) skip(message = 'SDMTools required for some tests - please install first')
 
   # Occurrence PA
   expect_true(x <- zoon:::test_module(paste0(basepath,
                                              "CWBZimbabwe.R")))
-  
+  # Model PA
+  expect_true(x <- zoon:::test_module(paste0(basepath,
+                                             "LogisticRegression.R"))) 
+  # Model PB
+  expect_true(x <- zoon:::test_module(paste0(basepath,
+                                             "MaxLike.R"))) 
+  # Occurrence PO
+  expect_true(x <- zoon:::test_module(paste0(basepath,
+                                             "CarolinaWrenPO.R")))
 })
